/*
    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

// Proxy-Require header

#ifndef _H_HDR_PROXY_REQUIRE
#define _H_HDR_PROXY_REQUIRE

#include <list>
#include <string>
#include "header.h"

class t_hdr_proxy_require : public t_header {
public:
	list<string>	features;

	t_hdr_proxy_require();
	void add_feature(const string &f);
	string encode(void) const;
	string encode_value(void) const;
	string encode_env(void) const;
};

#endif
